pub(crate) fn row_facts(row: &CreditRegistration) -> RowFactsExpand description
The scheduling history one outcome decision needs from a row.
pub(crate) fn row_facts(row: &CreditRegistration) -> RowFactsThe scheduling history one outcome decision needs from a row.