async fn run_preconditions(
ctx: &PhaseContext<'_>,
scope: &PhaseScope,
) -> Result<PhaseRunOutcome>Expand description
Database-only, so it keeps running while the study registry is unreachable.
async fn run_preconditions(
ctx: &PhaseContext<'_>,
scope: &PhaseScope,
) -> Result<PhaseRunOutcome>Database-only, so it keeps running while the study registry is unreachable.